@@ -1,16 +1,15 @@
 #include "common.h"
-#include <stdio.h>
+
 #include <ctype.h>
-#ifdef __EMX__
-#include <sys/types.h>
-#endif
-#include <sys/stat.h>
-#include <unistd.h>
-#include <sys/types.h>
 #include <dirent.h>
-#include <string.h>
-#include <stdlib.h>
 #include <pwd.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <unistd.h>
+#include <sys/stat.h>
+#include <sys/types.h>
+
 #include "file.h"
 
 char               *
@@ -258,7 +257,7 @@ __imlib_FileDir(char *dir, int *num)
         return (NULL);
      }
    /* count # of entries in dir (worst case) */
-   for (dirlen = 0; (dp = readdir(dirp)) != NULL; dirlen++);
+   for (dirlen = 0; (dp = readdir(dirp)); dirlen++);
    if (!dirlen)
      {
         closedir(dirp);
@@ -372,16 +371,18 @@ __imlib_FileHomeDir(int uid)
    char               *s;
    struct passwd      *pwd;
 
-#ifndef __EMX__
    s = getenv("HOME");
    if (s)
       return strdup(s);
+
    if (usr_uid < 0)
       usr_uid = getuid();
+
    if ((uid == usr_uid) && (usr_s))
      {
         return (strdup(usr_s));
      }
+
    pwd = getpwuid(uid);
    if (pwd)
      {
@@ -390,11 +391,6 @@ __imlib_FileHomeDir(int uid)
            usr_s = strdup(s);
         return (s);
      }
-#else
-   if ((s = getenv("HOME")) != NULL)
-      return strdup(s);
-   else if ((s = getenv("TMP")) != NULL)
-      return strdup(s);
-#endif
+
    return NULL;
 }
