@@ -1,15 +1,15 @@
 #ifndef _DYN_FUNCTION_H_
 #define _DYN_FUNCTION_H_
 
-#include <dlfcn.h>
+#include <stdarg.h>
+#include "common.h"
+#include "image.h"
 
 #ifndef BUILD_X11
-# ifndef X_DISPLAY_MISSING
-#  define X_DISPLAY_MISSING
-# endif
+#ifndef X_DISPLAY_MISSING
+#define X_DISPLAY_MISSING
+#endif
 #endif
-#include "Imlib2.h"
-#include <stdarg.h>
 
 #define VAR_CHAR 1
 #define VAR_PTR  2
@@ -37,34 +37,34 @@
 
 typedef struct _imlib_function_param IFunctionParam;
 typedef struct _imlib_function_param *pIFunctionParam;
-struct _imlib_function_param
-{
-   char            *key;
-   int              type;
-   void            *data;
-   pIFunctionParam  next;
+struct _imlib_function_param {
+   char               *key;
+   int                 type;
+   void               *data;
+   pIFunctionParam     next;
 };
 
 typedef struct _imlib_function IFunction;
 typedef struct _imlib_function *pIFunction;
-struct _imlib_function
-{
-   char            *name;
-   pIFunctionParam  params;
-   pIFunction        next;
+struct _imlib_function {
+   char               *name;
+   pIFunctionParam     params;
+   pIFunction          next;
 };
 
-typedef struct _imlib_variable
-{
-   void                   *ptr;
+typedef struct _imlib_variable {
+   void               *ptr;
    struct _imlib_variable *next;
 } IVariable;
 
-__hidden Imlib_Image     __imlib_script_parse( Imlib_Image im, char *script, va_list );
-__hidden IFunctionParam *__imlib_script_parse_parameters( Imlib_Image im, char *parameters );
-__hidden Imlib_Image     __imlib_script_parse_function( Imlib_Image im, char *function );
-__hidden void            __imlib_script_tidyup(void);
-__hidden void           *__imlib_script_get_next_var(void);
-__hidden void            __imlib_script_add_var( void *ptr );
+ImlibImage         *__imlib_script_parse(ImlibImage * im, char *script,
+                                         va_list);
+IFunctionParam     *__imlib_script_parse_parameters(ImlibImage * im,
+                                                    char *parameters);
+ImlibImage         *__imlib_script_parse_function(ImlibImage * im,
+                                                  char *function);
+void                __imlib_script_tidyup(void);
+void               *__imlib_script_get_next_var(void);
+void                __imlib_script_add_var(void *ptr);
 
 #endif /* _FUNCTION_H_ */
