@@ -10,9 +10,9 @@
  * header/footer structures courtesy of the GIMP Targa plugin 
  */
 #include "loader_common.h"
+#include <fcntl.h>
 #include <sys/stat.h>
 #include <sys/mman.h>
-#include "colormod.h"
 #include "blend.h"
 
 /* flip an inverted image - see RLE reading below */
@@ -237,6 +237,14 @@ load(ImlibImage * im, ImlibProgressFunction progress,
      {
      }
 
+   if ((size_t) ss.st_size < sizeof(tga_header) + header->idLength +
+       (footer_present ? sizeof(tga_footer) : 0))
+     {
+        munmap(seg, ss.st_size);
+        close(fd);
+        return 0;
+     }
+
    /* skip over header */
    filedata = (char *)filedata + sizeof(tga_header);
 
@@ -348,8 +356,14 @@ load(ImlibImage * im, ImlibProgressFunction progress,
                   else
                      dataptr = im->data + (y * im->w);
 
-                  for (x = 0; (x < im->w) && (bufptr + bpp / 8 <= bufend); x++) /* for each pixel in the row */
+                  for (x = 0; (x < im->w); x++) /* for each pixel in the row */
                     {
+                       if (bufptr + bpp / 8 > bufend)
+                         {
+                            munmap(seg, ss.st_size);
+                            close(fd);
+                            return 0;
+                         }
                        switch (bpp)
                          {
 
@@ -399,11 +413,17 @@ load(ImlibImage * im, ImlibProgressFunction progress,
              DATA32             *final_pixel = dataptr + im->w * im->h;
 
              /* loop until we've got all the pixels or run out of input */
-             while ((dataptr < final_pixel) &&
-                    ((bufptr + 1 + (bpp / 8)) <= bufend))
+             while ((dataptr < final_pixel))
                {
                   int                 count;
 
+                  if ((bufptr + 1 + (bpp / 8)) > bufend)
+                    {
+                       munmap(seg, ss.st_size);
+                       close(fd);
+                       return 0;
+                    }
+
                   curbyte = *bufptr++;
                   count = (curbyte & 0x7F) + 1;
 
@@ -457,9 +477,14 @@ load(ImlibImage * im, ImlibProgressFunction progress,
                     {
                        int                 i;
 
-                       for (i = 0; (i < count) && (dataptr < final_pixel) &&
-                            ((bufptr + (bpp / 8)) <= bufend); i++)
+                       for (i = 0; (i < count) && (dataptr < final_pixel); i++)
                          {
+                            if ((bufptr + 1 + (bpp / 8)) > bufend)
+                              {
+                                 munmap(seg, ss.st_size);
+                                 close(fd);
+                                 return 0;
+                              }
                             switch (bpp)
                               {
 
